package com.fastbee.data.controller.gis;

import java.util.List;

import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.ggroup.domain.dto.GLegendUpdateDto;
import com.fastbee.ggroup.domain.dto.GLegendDto;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.ggroup.domain.GLegend;
import com.fastbee.ggroup.service.IGLegendService;
import com.fastbee.common.core.page.TableDataInfo;

import javax.servlet.http.HttpServletResponse;

/**
 * 图例Controller
 *
 * @author kerwincui
 * @date 2024-10-08
 */
@RestController
@RequestMapping("/gis/legend")
@Api(tags = "图例")
public class GLegendController extends BaseController
{
    @Autowired
    private IGLegendService gLegendService;

/**
 * 查询/搜索图例列表
 */
@PreAuthorize("@ss.hasPermi('ggroup:legend:list')")
@GetMapping("/list")
@ApiOperation("查询图例列表")
    public TableDataInfo list(GLegend gLegend)
    {
        startPage();
        List<GLegendDto> list = gLegendService.selectGLegendList(gLegend);
        return getDataTable(list);
    }

    /**
     * 导出图例列表
     */
    @ApiOperation("导出图例列表")
    @PreAuthorize("@ss.hasPermi('ggroup:legend:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, GLegend gLegend)
    {
        List<GLegendDto> list = gLegendService.selectGLegendList(gLegend);
        ExcelUtil<GLegendDto> util = new ExcelUtil<GLegendDto>(GLegendDto.class);
        util.exportExcel(response, list, "图例数据");
    }

    /**
     * 获取图例详细信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:legend:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取图例详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gLegendService.selectGLegendById(id));
    }

    /**
     * 新增图例
     */
    @PreAuthorize("@ss.hasPermi('ggroup:legend:add')")
    @PostMapping
    @ApiOperation("新增图例")
    public AjaxResult add(@RequestBody GLegend gLegend)
    {
        return toAjax(gLegendService.insertGLegend(gLegend));
    }

    /**
     * 修改图例
     */
    @PreAuthorize("@ss.hasPermi('ggroup:legend:edit')")
    @PutMapping
    @ApiOperation("修改图例")
    public AjaxResult edit(@RequestBody GLegendUpdateDto gLegend)
    {
        return toAjax(gLegendService.updateGLegend(gLegend));
    }

    /**
     * 删除图例
     */
    @PreAuthorize("@ss.hasPermi('ggroup:legend:remove')")
    @DeleteMapping("/{ids}")
    @ApiOperation("删除图例")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gLegendService.deleteGLegendByIds(ids));
    }

    /**
     * 获取图例按照类别划分列表
     */
    @PreAuthorize("@ss.hasPermi('ggroup:legend:list')")
    @GetMapping("/category-list")
    @ApiOperation("获取图例按照类别划分列表")
    public AjaxResult listByCategory(GLegend gLegend){
        return success(gLegendService.getLegendListByCategory());
    }





}
