package com.fastbee.data.controller.gis;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletResponse;

import com.fastbee.ggroup.enums.GroupTagEnum;
import com.fastbee.ggroup.enums.SiteTypeCategoryEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.annotation.Log;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.common.enums.BusinessType;
import com.fastbee.ggroup.domain.GLegendType;
import com.fastbee.ggroup.service.IGLegendTypeService;
import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.common.core.page.TableDataInfo;

/**
 * 图例类型Controller
 *
 * @author kerwincui
 * @date 2024-10-09
 */
@RestController
@RequestMapping("/gis/legend/type")
@Api(tags = "图例类型")
public class GLegendTypeController extends BaseController
{
    @Autowired
    private IGLegendTypeService gLegendTypeService;

/**
 * 查询图例类型列表
 */
@PreAuthorize("@ss.hasPermi('ggroup:type:list')")
@GetMapping("/list")
@ApiOperation("查询图例类型列表")
    public TableDataInfo list(GLegendType gLegendType)
    {
        startPage();
        List<GLegendType> list = gLegendTypeService.selectGLegendTypeList(gLegendType);
        return getDataTable(list);
    }

    /**
     * 获取图例类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:type:info')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取图例类型详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gLegendTypeService.selectGLegendTypeById(id));
    }
    /**
     *获取图例的类别列表
     */
    @PreAuthorize("@ss.hasPermi('ggroup:type:category')")
    @GetMapping(value = "/category/list")
    @ApiOperation("获取图例的类别列表")
    public AjaxResult typeList()
    {
        List<Map<String, Object>> labelList = new ArrayList<>();
        for (SiteTypeCategoryEnum categoryEnum : SiteTypeCategoryEnum.values()) {
            Map<String, Object> map = new HashMap<>();
            map.put("name", categoryEnum.getName());
            labelList.add(map);
        }
        return AjaxResult.success(labelList);
    }





}
