package com.fastbee.ggroup.service;

import java.util.List;
import com.fastbee.ggroup.domain.GSites;
import com.fastbee.ggroup.domain.dto.GGroupSiteDto;
import com.fastbee.ggroup.domain.dto.GGroupSiteRelateDto;
import com.fastbee.ggroup.domain.dto.GSitesEditDto;
import com.fastbee.ggroup.domain.dto.GSitesSelectDto;

/**
 * 站点Service接口
 * 
 * @author kerwincui
 * @date 2024-09-29
 */
public interface IGSitesService 
{
    /**
     * 查询站点
     * 
     * @param id 站点主键
     * @return 站点
     */
    public GSites selectGSitesById(Long id);

    /**
     * 查询站点列表
     * 
     * @param gSites 站点
     * @return 站点集合
     */
    public List<?> selectGSitesList(GSitesSelectDto gSites);

    /**
     * 新增站点
     * 
     * @param gGroupSiteDto 站点
     * @return 结果
     */
    public int insertGSites(GGroupSiteDto gGroupSiteDto);

    /**
     * 修改站点
     * 
     * @param gSitesEditDto 站点
     * @return 结果
     */
    public int updateGSites(GSitesEditDto gSitesEditDto);

    /**
     * 批量删除站点
     * 
     * @param ids 需要删除的站点主键集合
     * @return 结果
     */
    public int deleteGSitesByIds(Long[] ids);

    /**
     * 删除站点信息
     * 
     * @param id 站点主键
     * @return 结果
     */
    public int deleteGSitesById(Long id);

    /**
     * 站点关联组
     *
     * @param gGroupSiteRelateDto
     * @return
     */
    int relateGroup(GGroupSiteRelateDto gGroupSiteRelateDto);

    /**
     * 搜索站点列表
     * @param gSites
     * @return
     */
    List<GSites> searchGSitesList(GSites gSites);
}
