package com.fastbee.ggroup.service.impl;


import cn.hutool.extra.ssh.JschUtil;
import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.fastbee.common.utils.DateUtils;
import com.fastbee.ggroup.domain.GGroups;
import com.fastbee.ggroup.domain.GSiteGroups;
import com.fastbee.ggroup.domain.GSites;
import com.fastbee.ggroup.domain.vo.GGroupSiteVo;
import com.fastbee.ggroup.mapper.GGroupsMapper;
import com.fastbee.ggroup.mapper.GSiteGroupsMapper;
import com.fastbee.ggroup.mapper.GSitesMapper;
import com.fastbee.ggroup.service.IGGroupsService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.yulichang.wrapper.MPJLambdaWrapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;



/**
 * 组Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-09-27
 */
@Service
public class GGroupsServiceImpl implements IGGroupsService
{
    @Autowired
    private GGroupsMapper gGroupsMapper;

    @Autowired
    private GSitesMapper gSitesMapper;

    @Autowired
    private GSiteGroupsMapper gSiteGroupsMapper;

    /**
     * 查询组
     * 
     * @param id 组主键
     * @return 组
     */
    @Override
    public GGroups selectGGroupsById(Long id)
    {
        return gGroupsMapper.selectGGroupsById(id);
    }


    /**
     * 查询组列表
     * 
     * @param gGroups 组
     * @return 组
     */
    @Override
    public List<GGroups> selectGGroupsList(GGroups gGroups)
    {
        return buildTree(gGroupsMapper.selectGGroupsList(gGroups));
    }

    /**
     * 查询/搜索组列表
     *
     * @param gGroups 组
     * @return 组
     */
    @Override
    public List<GGroupSiteVo> selectGGroupsListSites(GGroups gGroups) {
        return gGroupsMapper.selectGGroupsSiteList(gGroups);
    }

    private List<GGroups> buildTree(List<GGroups> groups) {
        Map<Long, GGroups> map = new HashMap<>();
        List<GGroups> roots = new ArrayList<>();
        for (GGroups group : groups) {
            map.put(group.getId(), group);
        }
        return getgGroups(groups, map, roots);
    }

    /**
     * 组合组树状结构列表
     */
    private List<GGroups> getgGroups(List<GGroups> groups, Map<Long, GGroups> map, List<GGroups> roots) {
        for (GGroups group : groups) {
            Long parentId = group.getParentId();
            if (parentId == null || !map.containsKey(parentId)) {
                roots.add(group);
            } else {
                GGroups parent = map.get(parentId);
                if (parent.getChildren() == null) {
                    parent.setChildren(new ArrayList<>());
                }
                parent.getChildren().add(group);
            }
        }
        return roots;
    }

    private List<GGroups> buildTreeSite(List<GGroups> groupsList) {
        // 构建一个Map，用于存储每个组对象:id->组对象
        Map<Long, GGroups> map = new HashMap<>();
        //根组列表
        List<GGroups> roots = new ArrayList<>();
        for (GGroups group : groupsList) {
            //查询组的直接子站点列表
            //TODO 优化为查询出所有站点列表，内存中处理
            List<GGroupSiteVo> gGroupSiteVoList  =  gGroupsMapper.selectGGroupsSiteList(GGroups.builder()
                    .parentId(group.getId())
                    .build());
            //将子站点列表添加到组对象中
            List<GGroups> childrenList= group.getChildren();
            gGroupSiteVoList.forEach(site->{
                childrenList.add(GGroups.builder()
                        .id(site.getId())
                        .name(site.getName())
                        .icon(site.getIcon())
                        .space(site.getSpace())
                        .spaceValue(site.getSpaceValue())
                        .nodeType(1)
                        .siteId(site.getId())
                        .build());
            });
            map.put(group.getId(), group);
        }
        //构建组树状结构
        return getgGroups(groupsList, map, roots);
    }

    /**
     * 新增组
     *
     * @param gGroups 组
     * @return 结果
     */
    @Override
    public int insertGGroups(GGroups gGroups)
    {
        gGroups.setCreateTime(DateUtils.getNowDate());
        return gGroupsMapper.insertGGroups(gGroups);
    }

    /**
     * 修改组
     * 
     * @param gGroups 组
     * @return 结果
     */
    @Override
    public int updateGGroups(GGroups gGroups)
    {
        gGroups.setUpdateTime(DateUtils.getNowDate());
        return gGroupsMapper.updateGGroups(gGroups);
    }

    /**
     * 批量删除组
     * 
     * @param ids 需要删除的组主键
     * @return 结果
     */
    @Override
    public int deleteGGroupsByIds(Long[] ids)
    {
        return gGroupsMapper.deleteGGroupsByIds(ids);
    }

    /**
     * 删除组信息
     * 
     * @param id 组主键
     * @return 结果
     */
    @Override
    public int deleteGGroupsById(Long id)
    {
        return gGroupsMapper.deleteGGroupsById(id);
    }

    /**
     * 查询组和站点的树状结构
     * @param gGroups 组
     * @return 列表
     */
    @Override
    public List<?> selectGGroupsAndSitesList(GGroups gGroups) {
        //组的树状结构
        return buildTreeSite(gGroupsMapper.selectGGroupsList(gGroups));
    }
}
