package com.fastbee.ggroup.service.impl;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.fastbee.common.utils.DateUtils;
import com.fastbee.ggroup.enums.SiteTypeCategoryEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.ggroup.mapper.GLegendTypeMapper;
import com.fastbee.ggroup.domain.GLegendType;
import com.fastbee.ggroup.service.IGLegendTypeService;

/**
 * 图例类型Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-10-09
 */
@Service
public class GLegendTypeServiceImpl implements IGLegendTypeService 
{
    @Autowired
    private GLegendTypeMapper gLegendTypeMapper;

    /**
     * 查询图例类型
     * 
     * @param id 图例类型主键
     * @return 图例类型
     */
    @Override
    public GLegendType selectGLegendTypeById(Long id)
    {
        return gLegendTypeMapper.selectGLegendTypeById(id);
    }

    /**
     * 查询图例类型列表
     * 
     * @param gLegendType 图例类型
     * @return 图例类型
     */
    @Override
    public List<GLegendType> selectGLegendTypeList(GLegendType gLegendType)
    {
        return gLegendTypeMapper.selectGLegendTypeList(gLegendType);
    }

    /**
     * 新增图例类型
     * 
     * @param gLegendType 图例类型
     * @return 结果
     */
    @Override
    public int insertGLegendType(GLegendType gLegendType)
    {
        gLegendType.setCreateTime(DateUtils.getNowDate());
        return gLegendTypeMapper.insertGLegendType(gLegendType);
    }

    /**
     * 修改图例类型
     * 
     * @param gLegendType 图例类型
     * @return 结果
     */
    @Override
    public int updateGLegendType(GLegendType gLegendType)
    {
        gLegendType.setUpdateTime(DateUtils.getNowDate());
        return gLegendTypeMapper.updateGLegendType(gLegendType);
    }

    /**
     * 批量删除图例类型
     * 
     * @param ids 需要删除的图例类型主键
     * @return 结果
     */
    @Override
    public int deleteGLegendTypeByIds(Long[] ids)
    {
        return gLegendTypeMapper.deleteGLegendTypeByIds(ids);
    }

    /**
     * 删除图例类型信息
     * 
     * @param id 图例类型主键
     * @return 结果
     */
    @Override
    public int deleteGLegendTypeById(Long id)
    {
        return gLegendTypeMapper.deleteGLegendTypeById(id);
    }


}
