package com.fastbee.iot.service;

import java.util.List;
import com.fastbee.iot.domain.ModbusParams;

/**
 * 产品modbus配置参数Service接口
 * 
 * @author kerwincui
 * @date 2024-05-31
 */
public interface IModbusParamsService 
{
    /**
     * 查询产品modbus配置参数
     * 
     * @param id 产品modbus配置参数主键
     * @return 产品modbus配置参数
     */
    public ModbusParams selectModbusParamsById(Long id);

    /**
     * 查询产品modbus配置参数列表
     * 
     * @param modbusParams 产品modbus配置参数
     * @return 产品modbus配置参数集合
     */
    public List<ModbusParams> selectModbusParamsList(ModbusParams modbusParams);

    /**
     * 新增产品modbus配置参数
     * 
     * @param modbusParams 产品modbus配置参数
     * @return 结果
     */
    public int insertModbusParams(ModbusParams modbusParams);

    /**
     * 修改产品modbus配置参数
     * 
     * @param modbusParams 产品modbus配置参数
     * @return 结果
     */
    public int updateModbusParams(ModbusParams modbusParams);

    /**
     * 批量删除产品modbus配置参数
     * 
     * @param ids 需要删除的产品modbus配置参数主键集合
     * @return 结果
     */
    public int deleteModbusParamsByIds(Long[] ids);

    /**
     * 删除产品modbus配置参数信息
     * 
     * @param id 产品modbus配置参数主键
     * @return 结果
     */
    public int deleteModbusParamsById(Long id);

    /**
     * 根据产品io获取modbus配置
     * @param productId
     * @return
     */
    ModbusParams getModbusParamsByProductId(Long productId);

    /**
     * 根据设备id获取modbus配置
     * @param deviceId
     * @return
     */
    ModbusParams getModbusParamsByDeviceId(Long deviceId);
}
