package com.fastbee.project.service.impl;

import com.fastbee.common.utils.DateUtils;
import com.fastbee.project.domain.Project;
import com.fastbee.project.mapper.ProjectMapper;
import com.fastbee.project.service.IProjectService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 项目Service业务层处理
 *
 * @author kerwincui
 * @date 2024-09-26
 */
@Service
public class ProjectServiceImpl implements IProjectService
{
        @Autowired
        private ProjectMapper projectMapper;

        /**
         * 查询项目
         *
         * @param projectId 项目主键
         * @return 项目
         */
        @Override
        public Project selectProjectByProjectId(Long projectId)
        {
                return projectMapper.selectProjectByProjectId(projectId);
        }

        /**
         * 查询项目列表
         *
         * @param project 项目
         * @return 项目
         */
        @Override
        public List<Project> selectProjectList(Project project)
        {
                return projectMapper.selectProjectList(project);
        }

        /**
         * 新增项目
         *
         * @param project 项目
         * @return 结果
         */
        @Override
        public int insertProject(Project project)
        {
                project.setCreateTime(DateUtils.getNowDate());
                return projectMapper.insertProject(project);
        }

        /**
         * 修改项目
         *
         * @param project 项目
         * @return 结果
         */
        @Override
        public int updateProject(Project project)
        {
                project.setUpdateTime(DateUtils.getNowDate());
                return projectMapper.updateProject(project);
        }

        /**
         * 批量删除项目
         *
         * @param projectIds 需要删除的项目主键
         * @return 结果
         */
        @Override
        public int deleteProjectByProjectIds(Long[] projectIds)
        {
                return projectMapper.deleteProjectByProjectIds(projectIds);
        }

        /**
         * 删除项目信息
         *
         * @param projectId 项目主键
         * @return 结果
         */
        @Override
        public int deleteProjectByProjectId(Long projectId)
        {
                return projectMapper.deleteProjectByProjectId(projectId);
        }
}

